-----------------------------------------------------------------------
-- tb_cu.vhd - Test bench for npkips cu.
-----------------------------------------------------------------------
LiBRARY IEEE;
USE work.ALL;
USE IEEE.std_logic_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;
use pkg_npkips.all;
ENTITY TB IS
END ENTITY TB;

ARCHITECTURE TEST of TB is
    signal Reset:   std_logic := '1';
    signal CLK:     std_logic := '0';
    signal S: A_STATE; -- Type A_STADE is defined in PKG_NPKIPS.VHD
    signal op: std_logic_vector(5 downto 0);
    signal func: std_logic_vector(5 downto 0) := "100000";
    Type Inst_type is (J, BEQ, R_Type, LW, SW);
    signal inst: inst_type;
BEGIN
    U1: ENTITY work.cu(arch)
        PORT MAP
        (
         CLK => CLK,
         RES => Reset,
         OP => OP,
         FUNC => FUNC,
         S => S
        );
    CLK <= not CLK after 5 ns when Reset = '0' else '0';
    Reset <= '0' after 10 ns;
    process 
    begin
        op <= op_lw;
        wait on S;
        wait until s = s0;
        op <= op_sw;
        wait on S;
        wait until s = s0;
        op <= op_j;
        wait on S;
        wait until s = s0;
        op <= op_R_type;
        wait on S;
        wait until s = s0;
        op <= op_beq;
        wait on S;
        wait until s = s0;
    end process;
-- Set inst to mnemonic for current instruction
    process(op)
    begin
        case op is
            when op_lw => inst <= LW;
            when op_sw => inst <= sw;
            when op_R_type => inst <= R_type;
            when op_J => inst <= J;
            when op_beq => inst <= BEQ;
            when others => null;
        end case;
    end process;    
END ARCHITECTURE TEST;






